<?php

/**
 * NoCAPTCHA
 *
 * @author  emanuele
 * @license BSD http://opensource.org/licenses/BSD-3-Clause
 *
 * @version 0.0.1
 *
 */

if (!defined('ELK'))
	die('No access...');

/**
 * A demo addon to show how to create a simple new anti-spam
 * measure and let ElkArte use it
 */

/**
 * This function adds the test to the list of known ones
 */
class NoCAPTCHA
{
	public static function control_verifications(&$known_verifications)
	{
		$known_verifications[] = 'NoCAPTCHA';
		loadLanguage('NoCAPTCHA');
	}
}

class Control_Verification_NoCAPTCHA implements Control_Verifications
{
	private $_options = null;
	private $_tested = false;

	public function __construct($verificationOptions = null)
	{
		if (!empty($verificationOptions))
			$this->_options = $verificationOptions;
	}
		
	public function showVerification($isNew, $force_refresh = true)
	{
		global $modSettings;

		$this->_tested = false;

		return !empty($modSettings['configure_verification_NoCAPTCHA_enable']) && !empty($modSettings['configure_verification_NoCAPTCHA_sitekey']);
	}

	public function createTest($refresh = true)
	{
	}

	public function prepareContext()
	{
		global $context;

		loadTemplate('NoCAPTCHA');
		addJavascriptFile('https://www.google.com/recaptcha/api.js');
		$context['configure_verification_NoCAPTCHA_sitekey'] = $modSettings['configure_verification_NoCAPTCHA_sitekey'];

		return array(
			'template' => 'NoCAPTCHA',
			'values' => array(
				'value' => null,
				'is_error' => $this->_tested && !$this->_verifyAnswer(),
			)
		);
	}

	public function doTest()
	{
		$this->_tested = true;

		if (!$this->_verifyAnswer())
			return 'NoCAPTCHA_failed';

		return true;
	}

	public function hasVisibleTemplate()
	{
		return true;
	}

	public function settings()
	{
		global $txt, $scripturl, $modSettings;

		// Visual verification.
		$config_vars = array(
			array('title', 'configure_verification_NoCAPTCHA'),
			array('desc', 'configure_verification_NoCAPTCHA_desc'),
			array('check', 'configure_verification_NoCAPTCHA_enable'),
			array('text', 'configure_verification_NoCAPTCHA_sitekey'),
			array('text', 'configure_verification_NoCAPTCHA_secretkey'),
		);

		return $config_vars;
	}

	private function _verifyAnswer()
	{
		if (empty($_POST['g-recaptcha-response']))
			return false;

		// your secret key
		$secret = $modSettings['configure_verification_NoCAPTCHA_secretkey'];

		// empty response
		$response = null;
		require_once(EXTDIR . '/recaptchalib.php');

		// check secret key
		$reCaptcha = new ReCaptcha($secret);

		$response = $reCaptcha->verifyResponse(
				$_SERVER["REMOTE_ADDR"],
				$_POST["g-recaptcha-response"]
		);

		return $response != null && $response->success;
	}
}

